# Generated by Django 4.2 on 2023-05-08 12:29

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='css',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('css', models.TextField()),
                ('domain', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='sites.domains')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'css',
                'verbose_name_plural': 'Custom css',
            },
        ),
    ]



from django.contrib.auth.models import User
from django.db.models.signals import post_save
from django.dispatch import receiver

from bigsansar.contrib.account.models import userinfo


@receiver(post_save, sender=User)
def create_userinfo(sender, instance, created, **kwargs):
    if created:
        userinfo.objects.create(user=instance)



# Generated by Django 4.2 on 2023-06-02 13:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='visitor',
            field=models.IntegerField(default=0),
        ),
    ]
